from afeng_tools.fastapi_tool.common.po_service.po_service import PoService


class ResourcePoService(PoService):
    """
    使用示例：resource_po_service = ResourcePoService(app_info.db_code, ResourceInfoPo)
    """

    pass
