from afeng_tools.fastapi_tool.common.po_service.po_service import PoService


class SitemapPoService(PoService):
    """
    使用示例：sitemap_po_service = SitemapPoService(app_info.db_code, SitemapInfoPo)
    """

    pass
