from afeng_tools.fastapi_tool.common.po_service.po_service import PoService


class TagPoService(PoService):
    """
    使用示例：tag_po_service = TagPoService(app_info.db_code, TagInfoPo)
    """

    pass
